.. _sampling:

************************************
Sampling (`baseband_tasks.sampling`)
************************************

`~baseband_tasks.sampling` contains tasks for resampling a stream on a
new grid.

.. _sampling_api:

Reference/API
=============

.. automodapi:: baseband_tasks.sampling
   :no-inherited-members:
